.. _project_configuration:

Project configuration
=====================

You have two options for configuring your project: using the user interface settings or
providing a ``scancode-config.yml`` configuration file.

To configure your project using the user interface, refer to the instructions in the
:ref:`user_interface_project_settings` section.

Alternatively, you can provide a ``scancode-config.yml`` configuration file as part of
the project inputs with the ``--input-file`` option when using the
:ref:`command_line_interface`.


.. tip::
    You can generate the project configuration file from the
    :ref:`user_interface_project_settings` UI.
